/*
    This example script demonstrates the use of the script class 'ConfigFile'.
    
    The example is intended to be run multiple times, i.e. execute the script multiple 
    times and take a look at the script trace window where the results are plotted.
    Comments about what happens in this script are included below.
*/


#include "ConfigFile.as"


const string CFG_FILE_NAME = "ScriptSettings.dat";

// The config file object
ConfigFile theFile(CFG_FILE_NAME);

void main()
{
    bool success = theFile.Open();
    
    if (!success)
    {
        MessageBox("Unable to open file!");
    }
    
    // Read the file content and output it in the trace window.
    if (theFile.ReadContent())
    {
        Trace("File content read successfully:\r\n");
        Trace(theFile.mTestString1 + "\r\n");
        Trace(theFile.mTestDouble1 + "\r\n");
        Trace(theFile.mTestString2 + "\r\n");
        Trace(theFile.mTestInt1 + "\r\n");
        
        // Now modify the data members and write them to file again.
        theFile.mTestString1 += " Appendix ";
        theFile.mTestString2 += " Appendix ";
        theFile.mTestDouble1 += 0.1245;
        theFile.mTestInt1 -= 3;
        
        Trace("Write modified settings now...\r\n");
        bool success = theFile.WriteContent();
        
        if (success)
        {
            Trace("File successfully written\r\n");
        }
        else
        {
            MessageBox("Unable to write file!");
        }
    }
    else
    {
        // Error reading all data from the file. Set defaults and write file newly.
        Trace("Can't read file content. Load and save defaults now...\r\n");
        theFile.LoadDefaults();
        success = theFile.WriteContent();
        
        if (success)
        {
            Trace("File successfully written\r\n");
        }
        else
        {
            MessageBox("Unable to write file!");
        }
    }
    
    // Close the file
    theFile.Close();
}
